@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-from utils.debug import *
-
 from collections import deque
 
 import numpy
@@ -750,10 +748,6 @@ class Graph:
         Eig  = Eig2.I.T
         node = newNode.T
 
-        ## debug(U.shape, prefix="U")
-        ## debug(Eig2.shape, prefix="Eig")
-        ## debug(node.shape, prefix="node")
-        ## debug(incidMatrix.shape, prefix="IncidenceMatrix")
         
         node = node * U * Eig2
         
